@@ -1,5 +1,5 @@
 /*
- * $Id: example.cpp,v 1.3 2001/09/03 22:11:55 sbooth Exp $ 
+ * $Id: example.cpp,v 1.7 2004/06/28 00:25:33 sbooth Exp $ 
  *
  * Skeleton of a CGI application written using the GNU cgicc library
  */
@@ -8,22 +8,11 @@
 #include <iostream>
 
 #include "cgicc/Cgicc.h"
-#include "cgicc/HTTPHeaders.h"
+#include "cgicc/HTTPHTMLHeader.h"
 #include "cgicc/HTMLClasses.h"
 
-// To use the debug logging feature, the variable gLogFile MUST be
-// defined, and it _must_ be an ofstream
-#if DEBUG
-  ofstream gLogFile( "/change_this_path/cgicc.log", ios::app );
-#endif
-
-#if CGICC_USE_NAMESPACES
-  using namespace std;
-  using namespace cgicc;
-#else
-#  define div div_
-#  define select select_
-#endif
+using namespace std;
+using namespace cgicc;
 
 int
 main(int argc, 
